//
//  ViewController.m
//  AppnextMoPubAdapterTest
//
//  Created by Eran Mausner on 10/01/2016.
//  Copyright © 2016 Appnext. All rights reserved.
//

#import "ViewController.h"

#if __has_include(<MoPub/MoPub.h>)
#import <MoPub/MoPub.h>
#else
#import "MoPub.h"
#import "MPInterstitialAdController.h"
#import "MPRewardedVideo.h"
#import "MPRewardedVideoReward.h"
#endif
#import <AppnextMoPubAdapter/AppnextMoPubAdapter.h>

NSString *const kCustomEventInterstitialAdUnitID = @"Your Ad Unit for Interstitial"; // Your Ad Unit for Interstitial
NSString *const kCustomEventCustomisedInterstitialAdUnitID = @"Your Ad Unit for Customised Interstitial"; // Your Ad Unit for Customised Interstitial
NSString *const kCustomEventFullScreenAdUnitID = @"Your Ad Unit for Full Screen Video"; // Your Ad Unit for Full Screen Video
NSString *const kCustomEventCustomisedFullScreenAdUnitID = @"Your Ad Unit for Customised Full Screen Video"; // Your Ad Unit for Customised Full Screen Video
NSString *const kCustomEventRewardedAdUnitID = @"Your Ad Unit for Rewarded Video"; // Your Ad Unit for Rewarded Video
NSString *const kCustomEventCustomisedRewardedAdUnitID = @"Your Ad Unit for Customised Rewarded Video"; // Your Ad Unit for Customised Rewarded Video
NSString *const kRealRewardedAdUnitID = @"Your Ad Unit for Real Rewarded Video"; // Your Ad Unit for Real Rewarded Video

@interface ViewController ()<MPInterstitialAdControllerDelegate, MPRewardedVideoDelegate>

@property (nonatomic, strong) IBOutlet UILabel *label;
@property (nonatomic, strong) IBOutlet UIButton *loadInterstitialButton;
@property (nonatomic, strong) IBOutlet UIButton *showInterstitialButton;
@property (nonatomic, strong) IBOutlet UIButton *loadCustomisedInterstitialButton;
@property (nonatomic, strong) IBOutlet UIButton *showCustomisedInterstitialButton;
@property (nonatomic, strong) IBOutlet UIButton *loadFullScreenButton;
@property (nonatomic, strong) IBOutlet UIButton *showFullScreenButton;
@property (nonatomic, strong) IBOutlet UIButton *loadCustomisedFullScreenButton;
@property (nonatomic, strong) IBOutlet UIButton *showCustomisedFullScreenButton;
@property (nonatomic, strong) IBOutlet UIButton *loadRewardedButton;
@property (nonatomic, strong) IBOutlet UIButton *showRewardedButton;
@property (nonatomic, strong) IBOutlet UIButton *loadCustomisedRewardedButton;
@property (nonatomic, strong) IBOutlet UIButton *showCustomisedRewardedButton;
@property (nonatomic, strong) IBOutlet UIButton *loadRealRewardedButton;
@property (nonatomic, strong) IBOutlet UIButton *showRealRewardedButton;

@property (nonatomic, strong) MPInterstitialAdController *customEventInterstitial;
@property (nonatomic, strong) MPInterstitialAdController *customEventCustomisedInterstitial;
@property (nonatomic, strong) MPInterstitialAdController *customEventFullScreen;
@property (nonatomic, strong) MPInterstitialAdController *customEventCustomisedFullScreen;
@property (nonatomic, strong) MPInterstitialAdController *customEventRewarded;
@property (nonatomic, strong) MPInterstitialAdController *customEventCustomisedRewarded;

@end

@implementation ViewController

- (void) viewDidLoad
{
    [super viewDidLoad];
    self.showInterstitialButton.hidden = YES;
    self.showCustomisedInterstitialButton.hidden = YES;
    self.showFullScreenButton.hidden = YES;
    self.showCustomisedFullScreenButton.hidden = YES;
    self.showRewardedButton.hidden = YES;
    self.showCustomisedRewardedButton.hidden = YES;
    self.showRealRewardedButton.hidden = YES;

    // Initialize rewarded video before loading any ads.
    [[MoPub sharedInstance] initializeRewardedVideoWithGlobalMediationSettings:nil delegate:self];
}

- (void) dealloc
{
    [[MoPub sharedInstance] initializeRewardedVideoWithGlobalMediationSettings:nil delegate:nil];
}

#pragma mark - Actions

- (IBAction) loadInterstitial:(id)sender
{
    if (self.customEventInterstitial)
    {
        self.customEventInterstitial.delegate = nil;
        [MPInterstitialAdController removeSharedInterstitialAdController:self.customEventInterstitial];
        self.customEventInterstitial = nil;
        self.showInterstitialButton.hidden = YES;
    }

    // Instantiate the interstitial using the class convenience method.
    self.customEventInterstitial = [MPInterstitialAdController interstitialAdControllerForAdUnitId:kCustomEventInterstitialAdUnitID];
    if (self.customEventInterstitial)
    {
        self.customEventInterstitial.delegate = self;
        // Fetch the interstitial ad.
        [self.customEventInterstitial loadAd];
    }
    else
    {
        self.label.text = @"ERROR Instantiating Interstitial";
    }
}

- (IBAction) showInterstitial:(id)sender
{
    if (self.customEventInterstitial.ready)
    {
        [self.customEventInterstitial showFromViewController:self];
    }
    else
    {
        // The interstitial wasn't ready, so continue as usual.
        self.label.text = @"Interstitial Not Ready";
    }
}

- (IBAction) loadCustomisedInterstitial:(id)sender
{
    if (self.customEventCustomisedInterstitial)
    {
        self.customEventCustomisedInterstitial.delegate = nil;
        [MPInterstitialAdController removeSharedInterstitialAdController:self.customEventCustomisedInterstitial];
        self.customEventCustomisedInterstitial = nil;
        self.showCustomisedInterstitialButton.hidden = YES;
    }
    
    // Instantiate the customised interstitial using the class convenience method.
    self.customEventCustomisedInterstitial = [MPInterstitialAdController interstitialAdControllerForAdUnitId:kCustomEventCustomisedInterstitialAdUnitID];
    if (self.customEventCustomisedInterstitial)
    {
        self.customEventCustomisedInterstitial.delegate = self;
        // Fetch the customised interstitial ad.
        [self.customEventCustomisedInterstitial loadAd];
    }
    else
    {
        self.label.text = @"ERROR Instantiating Customised Interstitial";
    }
}

- (IBAction) showCustomisedInterstitial:(id)sender
{
    if (self.customEventCustomisedInterstitial.ready)
    {
        [self.customEventCustomisedInterstitial showFromViewController:self];
    }
    else
    {
        // The customised interstitial wasn't ready, so continue as usual.
        self.label.text = @"Customised Interstitial Not Ready";
    }
}

- (IBAction) loadFullScreen:(id)sender
{
    if (self.customEventFullScreen)
    {
        self.customEventFullScreen.delegate = nil;
        [MPInterstitialAdController removeSharedInterstitialAdController:self.customEventFullScreen];
        self.customEventFullScreen = nil;
        self.showFullScreenButton.hidden = YES;
    }
    
    // Instantiate the FullScreen using the class convenience method.
    self.customEventFullScreen = [MPInterstitialAdController interstitialAdControllerForAdUnitId:kCustomEventFullScreenAdUnitID];
    if (self.customEventFullScreen)
    {
        self.customEventFullScreen.delegate = self;
        // Fetch the FullScreen ad.
        [self.customEventFullScreen loadAd];
    }
    else
    {
        self.label.text = @"ERROR Instantiating FullScreen";
    }
}

- (IBAction) showFullScreen:(id)sender
{
    if (self.customEventFullScreen.ready)
    {
        [self.customEventFullScreen showFromViewController:self];
    }
    else
    {
        // The FullScreen wasn't ready, so continue as usual.
        self.label.text = @"FullScreen Not Ready";
    }
}

- (IBAction) loadCustomisedFullScreen:(id)sender
{
    if (self.customEventCustomisedFullScreen)
    {
        self.customEventCustomisedFullScreen.delegate = nil;
        [MPInterstitialAdController removeSharedInterstitialAdController:self.customEventCustomisedFullScreen];
        self.customEventCustomisedFullScreen = nil;
        self.showCustomisedFullScreenButton.hidden = YES;
    }
    
    // Instantiate the customised FullScreen using the class convenience method.
    self.customEventCustomisedFullScreen = [MPInterstitialAdController interstitialAdControllerForAdUnitId:kCustomEventCustomisedFullScreenAdUnitID];
    if (self.customEventCustomisedFullScreen)
    {
        self.customEventCustomisedFullScreen.delegate = self;
        // Fetch the customised FullScreen ad.
        [self.customEventCustomisedFullScreen loadAd];
    }
    else
    {
        self.label.text = @"ERROR Instantiating Customised FullScreen";
    }
}

- (IBAction) showCustomisedFullScreen:(id)sender
{
    if (self.customEventCustomisedFullScreen.ready)
    {
        [self.customEventCustomisedFullScreen showFromViewController:self];
    }
    else
    {
        // The customised FullScreen wasn't ready, so continue as usual.
        self.label.text = @"Customised FullScreen Not Ready";
    }
}

- (IBAction) loadRewarded:(id)sender
{
    if (self.customEventRewarded)
    {
        self.customEventRewarded.delegate = nil;
        [MPInterstitialAdController removeSharedInterstitialAdController:self.customEventRewarded];
        self.customEventRewarded = nil;
        self.showRewardedButton.hidden = YES;
    }
    
    // Instantiate the Rewarded using the class convenience method.
    self.customEventRewarded = [MPInterstitialAdController interstitialAdControllerForAdUnitId:kCustomEventRewardedAdUnitID];
    if (self.customEventRewarded)
    {
        self.customEventRewarded.delegate = self;
        // Fetch the Rewarded ad.
        [self.customEventRewarded loadAd];
    }
    else
    {
        self.label.text = @"ERROR Instantiating Rewarded";
    }
}

- (IBAction) showRewarded:(id)sender
{
    if (self.customEventRewarded.ready)
    {
        [self.customEventRewarded showFromViewController:self];
    }
    else
    {
        // The Rewarded wasn't ready, so continue as usual.
        self.label.text = @"Rewarded Not Ready";
    }
}

- (IBAction) loadCustomisedRewarded:(id)sender
{
    if (self.customEventCustomisedRewarded)
    {
        self.customEventCustomisedRewarded.delegate = nil;
        [MPInterstitialAdController removeSharedInterstitialAdController:self.customEventCustomisedRewarded];
        self.customEventCustomisedRewarded = nil;
        self.showCustomisedRewardedButton.hidden = YES;
    }
    
    // Instantiate the customised Rewarded using the class convenience method.
    self.customEventCustomisedRewarded = [MPInterstitialAdController interstitialAdControllerForAdUnitId:kCustomEventCustomisedRewardedAdUnitID];
    if (self.customEventCustomisedRewarded)
    {
        self.customEventCustomisedRewarded.delegate = self;
        // Fetch the customised Rewarded ad.
        [self.customEventCustomisedRewarded loadAd];
    }
    else
    {
        self.label.text = @"ERROR Instantiating Customised Rewarded";
    }
}

- (IBAction) showCustomisedRewarded:(id)sender
{
    if (self.customEventCustomisedRewarded.ready)
    {
        [self.customEventCustomisedRewarded showFromViewController:self];
    }
    else
    {
        // The customised Rewarded wasn't ready, so continue as usual.
        self.label.text = @"Customised Rewarded Not Ready";
    }
}

- (IBAction) loadRealRewarded:(id)sender
{
    AppnextMoPubGlobalMediationSettings *appnextSettings = [[AppnextMoPubGlobalMediationSettings alloc] init];
    appnextSettings.config = [[AppnextRewardedVideoAdConfiguration alloc] init];
    appnextSettings.config.buttonText = @"Test";
    [MPRewardedVideo loadRewardedVideoAdWithAdUnitID:kRealRewardedAdUnitID withMediationSettings:@[appnextSettings]];
}

- (IBAction) showRealRewarded:(id)sender
{
    if ([MPRewardedVideo hasAdAvailableForAdUnitID:kRealRewardedAdUnitID])
    {
        [MPRewardedVideo presentRewardedVideoAdForAdUnitID:kRealRewardedAdUnitID fromViewController:self];
    }
    else
    {
        // The real Rewarded wasn't ready, so continue as usual.
        self.label.text = @"Real Rewarded Not Ready";
    }
}

#pragma mark MPInterstitialAdControllerDelegate implementation

- (void) interstitialDidLoadAd:(MPInterstitialAdController *)interstitial
{
    if (interstitial == self.customEventInterstitial)
    {
        self.label.text = @"Interstitial Did Load";
        self.showInterstitialButton.hidden = NO;
    }
    else if (interstitial == self.customEventCustomisedInterstitial)
    {
        self.label.text = @"Customised Interstitial Did Load";
        self.showCustomisedInterstitialButton.hidden = NO;
    }
    else if (interstitial == self.customEventFullScreen)
    {
        self.label.text = @"FullScreen Did Load";
        self.showFullScreenButton.hidden = NO;
    }
    else if (interstitial == self.customEventCustomisedFullScreen)
    {
        self.label.text = @"Customised FullScreen Did Load";
        self.showCustomisedFullScreenButton.hidden = NO;
    }
    else if (interstitial == self.customEventRewarded)
    {
        self.label.text = @"Rewarded Did Load";
        self.showRewardedButton.hidden = NO;
    }
    else if (interstitial == self.customEventCustomisedRewarded)
    {
        self.label.text = @"Customised Rewarded Did Load";
        self.showCustomisedRewardedButton.hidden = NO;
    }
}

- (void) interstitialDidFailToLoadAd:(MPInterstitialAdController *)interstitial
{
    if (interstitial == self.customEventInterstitial)
    {
        self.label.text = @"Interstitial Did Fail To Load";
        self.showInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedInterstitial)
    {
        self.label.text = @"Customised Interstitial Did Fail To Load";
        self.showCustomisedInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventFullScreen)
    {
        self.label.text = @"FullScreen Did Fail To Load";
        self.showFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedFullScreen)
    {
        self.label.text = @"Customised FullScreen Did Fail To Load";
        self.showCustomisedFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventRewarded)
    {
        self.label.text = @"Rewarded Did Fail To Load";
        self.showRewardedButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedRewarded)
    {
        self.label.text = @"Customised Rewarded Did Fail To Load";
        self.showCustomisedRewardedButton.hidden = YES;
    }
}

- (void) interstitialWillAppear:(MPInterstitialAdController *)interstitial
{
}

- (void) interstitialDidAppear:(MPInterstitialAdController *)interstitial
{
}

- (void) interstitialWillDisappear:(MPInterstitialAdController *)interstitial
{
    if (interstitial == self.customEventInterstitial)
    {
        self.showInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedInterstitial)
    {
        self.showCustomisedInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventFullScreen)
    {
        self.showFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedFullScreen)
    {
        self.showCustomisedFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventRewarded)
    {
        self.showRewardedButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedRewarded)
    {
        self.showCustomisedRewardedButton.hidden = YES;
    }
}

- (void) interstitialDidDisappear:(MPInterstitialAdController *)interstitial
{
    if (interstitial == self.customEventInterstitial)
    {
        self.showInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedInterstitial)
    {
        self.showCustomisedInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventFullScreen)
    {
        self.showFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedFullScreen)
    {
        self.showCustomisedFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventRewarded)
    {
        self.showRewardedButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedRewarded)
    {
        self.showCustomisedRewardedButton.hidden = YES;
    }
}

- (void) interstitialDidExpire:(MPInterstitialAdController *)interstitial
{
    if (interstitial == self.customEventInterstitial)
    {
        self.label.text = @"Interstitial Did Expire";
        self.showInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedInterstitial)
    {
        self.label.text = @"Customised Interstitial Did Expire";
        self.showCustomisedInterstitialButton.hidden = YES;
    }
    else if (interstitial == self.customEventFullScreen)
    {
        self.label.text = @"FullScreen Did Expire";
        self.showFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedFullScreen)
    {
        self.label.text = @"Customised FullScreen Did Expire";
        self.showCustomisedFullScreenButton.hidden = YES;
    }
    else if (interstitial == self.customEventRewarded)
    {
        self.label.text = @"Rewarded Did Expire";
        self.showRewardedButton.hidden = YES;
    }
    else if (interstitial == self.customEventCustomisedRewarded)
    {
        self.label.text = @"Customised Rewarded Did Expire";
        self.showCustomisedRewardedButton.hidden = YES;
    }
}

- (void) interstitialDidReceiveTapEvent:(MPInterstitialAdController *)interstitial
{
    if (interstitial == self.customEventInterstitial)
    {
        self.label.text = @"Interstitial Tapped";
    }
    else if (interstitial == self.customEventCustomisedInterstitial)
    {
        self.label.text = @"Customised Interstitial Tapped";
    }
    else if (interstitial == self.customEventFullScreen)
    {
        self.label.text = @"FullScreen Tapped";
    }
    else if (interstitial == self.customEventCustomisedFullScreen)
    {
        self.label.text = @"Customised FullScreen Tapped";
    }
    else if (interstitial == self.customEventRewarded)
    {
        self.label.text = @"Rewarded Tapped";
    }
    else if (interstitial == self.customEventCustomisedRewarded)
    {
        self.label.text = @"Customised Rewarded Tapped";
    }
}

#pragma mark MPRewardedVideoDelegate implementation

- (void) rewardedVideoAdDidLoadForAdUnitID:(NSString *)adUnitID
{
    self.label.text = @"Real Rewarded Did Load";
    self.showRealRewardedButton.hidden = NO;
}

- (void) rewardedVideoAdDidFailToLoadForAdUnitID:(NSString *)adUnitID error:(NSError *)error
{
    self.label.text = [NSString stringWithFormat:@"Real Rewarded Did Fail To Load %@", error.description];
    self.showRealRewardedButton.hidden = YES;
}

- (void) rewardedVideoAdDidExpireForAdUnitID:(NSString *)adUnitID
{
    self.label.text = @"Real Rewarded Did Expire";
    self.showRealRewardedButton.hidden = YES;
}

- (void) rewardedVideoAdDidFailToPlayForAdUnitID:(NSString *)adUnitID error:(NSError *)error
{
    self.label.text = [NSString stringWithFormat:@"Real Rewarded Did Fail To Play %@", error.description];
    self.showRealRewardedButton.hidden = YES;
}

- (void) rewardedVideoAdWillAppearForAdUnitID:(NSString *)adUnitID
{
}

- (void) rewardedVideoAdDidAppearForAdUnitID:(NSString *)adUnitID
{
}

- (void) rewardedVideoAdWillDisappearForAdUnitID:(NSString *)adUnitID
{
    self.showRealRewardedButton.hidden = YES;
}

- (void) rewardedVideoAdDidDisappearForAdUnitID:(NSString *)adUnitID
{
    self.showRealRewardedButton.hidden = YES;
}

- (void) rewardedVideoAdDidReceiveTapEventForAdUnitID:(NSString *)adUnitID
{
    self.label.text = @"Real Rewarded Tapped";
}

- (void) rewardedVideoAdWillLeaveApplicationForAdUnitID:(NSString *)adUnitID
{
}

- (void) rewardedVideoAdShouldRewardForAdUnitID:(NSString *)adUnitID reward:(MPRewardedVideoReward *)reward
{
    if (reward.amount.integerValue == kMPRewardedVideoRewardCurrencyAmountUnspecified)
    {
        self.label.text = [NSString stringWithFormat:@"Real Rewarded Rewarded User with undefined amount of %@", reward.currencyType];
    }
    else
    {
        self.label.text = [NSString stringWithFormat:@"Real Rewarded Rewarded User with %@ %@", reward.amount.stringValue, reward.currencyType];
    }
}

@end
